@@ -254,28 +254,36 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
             pybuild_install_args + " " + pybuild_user_install_args
         )
 
-    if action == "configure":
-        prefixes = env.get("CMAKE_PREFIX_PATH", None)
+    if action == "configure" and build_type == "ament_python":
+        if not args.dry_run:
+            pybuild_dir = args.sourcedir / ".pybuild"
+            if pybuild_dir.is_dir():
+                log.info(f"Removing {pybuild_dir}")
+                shutil.rmtree(pybuild_dir, ignore_errors=True)
+
+    prefixes = env.get("CMAKE_PREFIX_PATH", None)
+    prefixes = prefixes.split(":") if prefixes is not None else []
+    if install_prefix != Path("/usr"):
+        prefixes.append(str(install_prefix))
+    env["CMAKE_PREFIX_PATH"] = ":".join(
+        prefixes + [str(d / relative_install_prefix) for d in destdirs]
+    )
+    if build_type == "ament_cmake":
+        prefixes = env.get("AMENT_PREFIX_PATH", None)
         prefixes = prefixes.split(":") if prefixes is not None else []
         if install_prefix != Path("/usr"):
             prefixes.append(str(install_prefix))
-        env["CMAKE_PREFIX_PATH"] = ":".join(
+        env["AMENT_PREFIX_PATH"] = ":".join(
             prefixes + [str(d / relative_install_prefix) for d in destdirs]
         )
-        if build_type == "ament_cmake":
-            prefixes = env.get("AMENT_PREFIX_PATH", None)
-            prefixes = prefixes.split(":") if prefixes is not None else []
-            if install_prefix != Path("/usr"):
-                prefixes.append(str(install_prefix))
-            env["AMENT_PREFIX_PATH"] = ":".join(
-                prefixes + [str(d / relative_install_prefix) for d in destdirs]
-            )
-        if build_type == "ament_python":
-            if not args.dry_run:
-                pybuild_dir = args.sourcedir / ".pybuild"
-                if pybuild_dir.is_dir():
-                    log.info(f"Removing {pybuild_dir}")
-                    shutil.rmtree(pybuild_dir, ignore_errors=True)
+    if build_type == "catkin":
+        package_paths = env.get("ROS_PACKAGE_PATH", None)
+        package_paths = package_paths.split(":") if package_paths is not None else []
+        if install_prefix != Path("/usr"):
+            package_paths.append(str(install_prefix / "share"))
+        env["ROS_PACKAGE_PATH"] = ":".join(
+            package_paths + [str(d / relative_install_prefix / "share") for d in destdirs]
+        )
 
     pythonpaths = env.get("PYTHONPATH", None)
     pythonpaths = pythonpaths.split(":") if pythonpaths is not None else []
@@ -357,7 +365,7 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
                         "-DAMENT_CMAKE_ENVIRONMENT_PACKAGE_GENERATION=OFF",
                         "-DAMENT_CMAKE_ENVIRONMENT_PARENT_PREFIX_PATH_GENERATION=OFF",
                     ]
-        elif action == "test" and build_type == "catkin":
+        elif action == "test" and build_type == "catkin" and package.name != "catkin":
             cmdline += ["run_tests"]
 
         for extra_args_var in [
@@ -383,7 +391,7 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
         if not args.dry_run:
             subprocess.check_call(cmdline, env=env)
 
-            if action == "test" and build_type == "catkin":
+            if action == "test" and build_type == "catkin" and package.name != "catkin":
                 sys.stdout.write(f"{cmdind}catkin_test_results\n")
                 sys.stdout.flush()
                 subprocess.check_call("catkin_test_results", env=env)
